@@ -16,7 +16,7 @@ import hashlib
 import os
 from enum import Enum
 
-from superlinked.server.configuration.app_config import AppConfig
+from superlinked.server.configuration.settings import Settings
 
 
 class HashType(Enum):
@@ -24,13 +24,13 @@ class HashType(Enum):
 
 
 class FileHandlerService:
-    def __init__(self, app_config: AppConfig, hash_type: HashType | None = None) -> None:
+    def __init__(self, settings: Settings, hash_type: HashType | None = None) -> None:
         self.__hash_type = hash_type or HashType.MD5
-        self.app_config = app_config
+        self.settings = settings
 
     def generate_filename(self, app_id: str) -> str:
         filename = self.__hash_type.value(f"{app_id}".encode()).hexdigest()
-        return f"{self.app_config.PERSISTENCE_FOLDER_PATH}/{filename}.json"
+        return f"{self.settings.PERSISTENCE_FOLDER_PATH}/{filename}.json"
 
     def ensure_folder(self) -> None:
-        os.makedirs(self.app_config.PERSISTENCE_FOLDER_PATH, exist_ok=True)
+        os.makedirs(self.settings.PERSISTENCE_FOLDER_PATH, exist_ok=True)
